import React from 'react';
import { Tooltip, TooltipTrigger, TooltipContent, TooltipProvider } from '@graphpolaris/shared/lib/components/tooltip';
import styles from './NLPopUp.module.scss';

const formatNumber = (number: number) => {
  return number.toLocaleString('de-DE');
};

export type NLPopUpProps = {
  data: Record<string, any>;
};

export const NLPopUp: React.FC<NLPopUpProps> = ({ data }) => {
  return (
    <TooltipProvider delayDuration={300}>
      <div className={`px-2`}>
        {Object.keys(data).length === 0 ? (
          <div className="flex justify-center items-center h-full">
            <span>No attributes</span>
          </div>
        ) : (
          Object.entries(data).map(([k, v]) => (
            <Tooltip key={k}>
              <TooltipTrigger asChild>
                <div className="flex flex-row gap-1 items-center min-h-5">
                  <span className={`font-semibold truncate min-w-[40%]`}>{k}</span>
                  <span className="ml-auto text-right truncate grow-1 flex items-center">
                    {v !== undefined && (typeof v !== 'object' || Array.isArray(v)) && v != '' ? (
                      <span className="ml-auto text-right truncate">{typeof v === 'number' ? formatNumber(v) : v.toString()}</span>
                    ) : (
                      <div className={`ml-auto mt-auto h-4 w-12 ${styles['diagonal-lines']}`}></div>
                    )}
                  </span>
                </div>
              </TooltipTrigger>
              <TooltipContent side="right">
                <div className="max-w-[18rem] break-all line-clamp-6">
                  <span className="font-semibold">{k + ': '}</span>
                  <span>{v !== undefined && (typeof v !== 'object' || Array.isArray(v)) && v != '' ? v : 'noData'}</span>
                </div>
              </TooltipContent>
            </Tooltip>
          ))
        )}
      </div>
    </TooltipProvider>
  );
};
